@@ -200,9 +200,11 @@ static const FFCodec * const codec_list[] = {
     &ff_h264_amf_encoder,
     &ff_h264_v4l2m2m_encoder,
     &ff_h264_vaapi_encoder,
+    &ff_h264_vulkan_encoder,
     &ff_hevc_amf_encoder,
     &ff_hevc_v4l2m2m_encoder,
     &ff_hevc_vaapi_encoder,
+    &ff_hevc_vulkan_encoder,
     &ff_mjpeg_vaapi_encoder,
     &ff_mpeg2_vaapi_encoder,
     &ff_mpeg4_v4l2m2m_encoder,
